You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by je...@apache.org on 2020/04/11 14:28:05 UTC

[geode] branch develop updated: GEODE-7981: Change the redis default region type to PARTITION_REDUNDANT (#4945)

This is an automated email from the ASF dual-hosted git repository.

jensdeppe pushed a commit to branch develop
in repository https://gitbox.apache.org/repos/asf/geode.git


The following commit(s) were added to refs/heads/develop by this push:
     new bab8c29  GEODE-7981: Change the redis default region type to PARTITION_REDUNDANT (#4945)
bab8c29 is described below

commit bab8c297f1386ebe29d75a007479868a47a98a40
Author: Dan Smith <up...@apache.org>
AuthorDate: Sat Apr 11 07:27:32 2020 -0700

    GEODE-7981: Change the redis default region type to PARTITION_REDUNDANT (#4945)
    
    Change the redis API to have redundant regions by default.
---
 .../src/main/java/org/apache/geode/redis/GeodeRedisServer.java       | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/geode-redis/src/main/java/org/apache/geode/redis/GeodeRedisServer.java b/geode-redis/src/main/java/org/apache/geode/redis/GeodeRedisServer.java
index aa1dcf4..ed50a5e 100644
--- a/geode-redis/src/main/java/org/apache/geode/redis/GeodeRedisServer.java
+++ b/geode-redis/src/main/java/org/apache/geode/redis/GeodeRedisServer.java
@@ -301,12 +301,13 @@ public class GeodeRedisServer {
 
   /**
    * Determine the {@link RegionShortcut} type from a String value. If the String value doesn't map
    * to a RegionShortcut type then {@link RegionShortcut#PARTITION} will be used by default.
    *
    * @return {@link RegionShortcut}
    */
   private static RegionShortcut setRegionType() {
-    String regionType = System.getProperty(DEFAULT_REGION_SYS_PROP_NAME, "PARTITION");
+    String regionType = System.getProperty(DEFAULT_REGION_SYS_PROP_NAME, "PARTITION_REDUNDANT");
     RegionShortcut type;
     try {
       type = RegionShortcut.valueOf(regionType);
@@ -301,12 +301,13 @@ public class GeodeRedisServer {
   /**
    * Determine the {@link RegionShortcut} type from a String value. If the String value doesn't map
-   * to a RegionShortcut type then {@link RegionShortcut#PARTITION} will be used by default.
+   * to a RegionShortcut type then {@link RegionShortcut#PARTITION_REDUNDANT} will be used by
+   * default.
    *
    * @return {@link RegionShortcut}